function fluid = initFluid(fluid)
%Complete initialization of incompressible two-phase fluid model.
%
% SYNOPSIS:
%   fluid = initFluid(fluid)
%
% PARAMETERS:
%   fluid - fluid object to be processed.
%
% RETURNS:
%   fluid - Fluid data structure representing the current state of the
%           fluids within the reservoir model.
%
% NOTE:
%   The fluid model represented by the return argument is the two-phase
%   incompressible counterpart to the fluid model of the Black Oil 'pvt'
%   function.
%
% SEE ALSO:
%   pvt, initResSol, initWellSol, solveIncompFlow.

%{
Copyright 2009 SINTEF ICT, Applied Mathematics.

This file is part of The MATLAB Reservoir Simulation Toolbox (MRST).

MRST is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

MRST is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with MRST.  If not, see <http://www.gnu.org/licenses/>.
%}

% $Id: initFluid.m 1956 2009-03-31 11:06:38Z bska $


mob    = @(sol) bsxfun(@rdivide, fluid.kr(sol), fluid.mu);
totmob = @(sol) sum(mob(sol), 2);
omega  = @(sol) sum(bsxfun(@times,   fluid.rho./fluid.mu, ...
                                     fluid.kr(sol)),2)./totmob(sol);

fluid.mob   = mob;
fluid.Lt    = totmob;
fluid.omega = omega;
