function varargout = outlineCoarseGrid(G, p, varargin)
%Impose outline of coarse grid on existing grid plot.
%
% SYNOPSIS:
%       outlineCoarseGrid(G, p)
%       outlineCoarseGrid(G, p, 'pn1', pv1, ...)
%   h = outlineCoarseGrid(...)
%
% PARAMETERS:
%   G       - Grid data structure.
%
%   p       - Coarse grid partition vector as defined by (e.g) partitionUI
%             and processPartition.
%
%   'pn'/pv - List of PATCH property specifcations.
%
% RETURNS:
%   h - Handle to polygonal patch structure as defined by function
%       plotFaces.  OPTIONAL.
%
% EXAMPLE:
%   G  = cartGrid([8, 8, 2]);
%   p  = partitionUI(G, [2, 2, 1]);
%   % plot fine grid:  
%   plotGrid(G, 'faceColor', 'none'); view(3);
%   % outline coarse grid on fine grid:  
%   outlineCoarseGrid(G, p);
%
% SEE ALSO:
%   plotFaces, plotGrid, patch.

%{
Copyright 2009 SINTEF ICT, Applied Mathematics.

This file is part of The MATLAB Reservoir Simulation Toolbox (MRST).

MRST is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

MRST is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with MRST.  If not, see <http://www.gnu.org/licenses/>.
%}

% $Id: outlineCoarseGrid.m 1956 2009-03-31 11:06:38Z bska $

p = [0; p];
N = p(G.faces.neighbors + 1);
N = find((N(:,1) ~= N(:,2)) & (prod(N,2) > 0));

h = plotFaces(G, N, [0.85, 0.15, 0.85], varargin{:});

if nargout > 0, varargout{1} = h; end
